<?php
namespace inshok\admin\controllers\admin;

use inshok\admin\controllers\interfaces\InterfaceProcess;
use inshok\admin\helpers\Html;
use inshok\admin\helpers\Message;
use inshok\admin\helpers\Clear;

use inshok\admin\database\PdoUser;
use inshok\admin\entity\EntityAddress;
use inshok\admin\entity\EntityContacts;
use inshok\admin\entity\EntityDocuments;
use inshok\admin\entity\EntityUser;


class UserInsertController implements InterfaceProcess {

    use Html;

    public function process(): void
    {
        
        $action = filter_input( INPUT_GET , 'action' , FILTER_SANITIZE_STRING );
        if( empty($action) ) $action = 'insert';
        
        $user_id = filter_input( INPUT_GET , 'id' , FILTER_VALIDATE_INT );
        if( empty($user_id) ) $user_id = 0;
        


        // Recuperar a variável access do login
        $user_access = 1;
        
        
        $user = new EntityUser();
        $user->setId( $user_id );

        $user_pdo = new PdoUser();
        
        
        if( $_POST ) {

            
            $full_name = filter_input( INPUT_POST , 'full_name' , FILTER_SANITIZE_STRING );
            $full_name_explode = explode(' ' , $full_name);
            $user->setInstance( [
                'user_id' => $user_id,
                'name' => $full_name_explode[0],
                'lastname' => $full_name_explode[ count($full_name_explode)-1 ],
                'email' => filter_input( INPUT_POST , 'email' , FILTER_SANITIZE_STRING ),
            ] );
            
            $user_documents = new EntityDocuments();
            $user_documents->setInstance( [
                'cpf' => Clear::cpf( filter_input( INPUT_POST , 'cpf' , FILTER_SANITIZE_STRING ) ),
                'rg' => Clear::rg( filter_input( INPUT_POST , 'rg' , FILTER_SANITIZE_STRING ) ),
            ] );

            $user_contacts = new EntityContacts();
            $user_contacts->setInstance( [
                'whatsapp' => Clear::phone( filter_input( INPUT_POST , 'whatsapp' , FILTER_SANITIZE_STRING ) ),
            ] );

            
            $user_pdo_save = $user_pdo->save( $user );
            $user_message_return = $user_pdo_save['index_return'];
            
            
            if( $user_message_return == 2 ) {
                Message::set('E-mail já cadastrado' , 2);

            } elseif( $user_message_return == 3 ) {
                Message::set('Esse e-mail está sendo utilizado por outro usuário' , 2);
                
            } else {
                
                if( $action == 'insert' ) {
                    $user->setId( $user_pdo_save['v_user_id'] );
                }

                $user_pdo->saveContacts( $user , $user_contacts );
                $user_pdo->saveDocuments( $user , $user_documents );


                if( $user_message_return == 1 ) {
                    Message::set('Usuário alterado com sucesso' , 1);
                } else {
                    Message::set('Usuário cadastrado com sucesso' , 1);
                }
            }
        }
        
        
        if( $action == 'insert' ) {
            $title = 'Inserir';
        } elseif( $action == 'update' ) {
            $title = 'Alterar';
            
        }

        $args = [
            'pathJS' => 'user-insert.js',
            'access' => $user_access,
            'page_title' => $title . ' usuário',
            'button_label' => $title,
        ];
        
        if( Message::get() ) {
            $args['message_return'] = Message::get();
            Message::destroy();
        }

        
        if( $action == 'update' )  {
            
            $user_pdo_list = $user_pdo->listupdate( $user->getId() );
            $user->setInstance( $user_pdo_list );

            $contacts = new EntityContacts();
            $contacts->setInstance( $user_pdo_list );

            $documents = new EntityDocuments();
            $documents->setInstance( $user_pdo_list );


            if( !empty( $user_pdo_list ) ) {
                $args['user'] = json_decode( json_encode( $user ) );
                $args['contacts'] = json_decode( json_encode( $contacts ) );
                $args['documents'] = json_decode( json_encode( $documents ) );
            }
            
        } elseif( $action == 'insert' && $_POST) {

            if( $user_message_return == 2 ) {

                $args['user'] = json_decode( json_encode( $user ) );
                $args['contacts'] = json_decode( json_encode( $user_contacts ) );
                $args['documents'] = json_decode( json_encode( $user_documents ) );

            }

        }

        
        $path = 'admin/user-insert.php';
        echo $this->render($path , $args);
        

    }

}




