<?php 
namespace inshok\admin\database;

use \inshok\admin\database\ConnectionCreator;
use \inshok\admin\database\InterfaceBase;


use PDO;

class PdoCategory implements InterfaceBase
{

    public function __construct()
    {
        
        $this->connection = ConnectionCreator::createConnection();

    }

    public function list( $id ) 
    {

        $sqlInstruction = 'CALL p_list_category( :ID, :page, :num_register )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->bindValue(':page', 0 , PDO::PARAM_INT);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return [
            'id' => $data['category_id'],
            'key' => $data['category_key'],
            'name' => $data['category_name'],
            'description' => $data['category_description'],
            'text' => $data['category_text'],
            'hierarchy' => $data['category_hierarchy'],
            'depth' => $data['category_depth'],
            'dateregister' => $data['category_dateregister'],
        ];
    }
    
    public function fulllist( $page ) 
    {

        $sqlInstruction = 'CALL p_list_category( :ID, :page, :num_register )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', 0 , PDO::PARAM_INT);
        $statement->bindValue(':page', $page , PDO::PARAM_INT);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'category_id' => $data['category_id'],
                'key' => $data['category_key'],
                'name' => $data['category_name'],
                'description' => $data['category_description'],
                'text' => $data['category_text'],
                'hierarchy' => $data['category_hierarchy'],
                'depth' => $data['category_depth'],
                'category_dateregister' => $data['category_dateregister'],
            ];
        }

        return $data_array;
    }


    public function totallist() {
        
        $sqlInstruction = 'CALL p_list_category_count_pages( :num_register )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return $data['v_num_pages'];

    }

    public function save( $category )
    {

        $sqlInstruction = 'CALL p_save_category( :category_id, :category_key, :category_name, :category_description, :category_text, :category_hierarchy, :category_depth )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':category_id', $category->getId() , PDO::PARAM_INT);
        $statement->bindValue(':category_key', $category->getKey() , PDO::PARAM_STR);
        $statement->bindValue(':category_name', $category->getName() , PDO::PARAM_STR);
        $statement->bindValue(':category_description', $category->getDescription() , PDO::PARAM_STR);
        $statement->bindValue(':category_text', $category->getText() , PDO::PARAM_STR);
        $statement->bindValue(':category_hierarchy', $category->getHierarchy() , PDO::PARAM_INT);
        $statement->bindValue(':category_depth', $category->getDepth() , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    
    public function savedeleteTemplateCategory( $category , $template , $action )
    {

        $sqlInstruction = 'CALL p_save_delete_templatecategory( :category_id, :template_id, :action )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':category_id', $category->getId() , PDO::PARAM_INT);
        $statement->bindValue(':template_id', $template->getId() , PDO::PARAM_INT);
        $statement->bindValue(':action', $action , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }


    public function delete( $category )
    {

        $sqlInstruction = 'CALL p_delete_category( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $category->getId() , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC); 
    }

}


