<?php 
namespace inshok\admin\database;

use \inshok\admin\database\ConnectionCreator;
use \inshok\admin\database\InterfaceBase;


use PDO;

class PdoImage implements InterfaceBase
{

    public function __construct()
    {
        
        $this->connection = ConnectionCreator::createConnection();

    }

    public function list( $id ) 
    {

        $sqlInstruction = 'CALL p_list_image( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return [
            'id' => $data['image_id'],
            'key' => $data['image_key'],
            'path' => $data['image_path'],
            'name' => $data['image_name'],
            'description' => $data['image_description'],
            'extension' => $data['image_extension'],
            'type' => $data['image_type'],
            'header' => $data['image_header'],
            'dateregister' => $data['image_dateregister'],
        ];
    }
    
    public function fulllist() 
    {

        $sqlInstruction = 'CALL p_list_image( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', 0 , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['image_id'],
                'key' => $data['image_key'],
                'path' => $data['image_path'],
                'name' => $data['image_name'],
                'description' => $data['image_description'],
                'extension' => $data['image_extension'],
                'type' => $data['image_type'],
                'header' => $data['image_header'],
                'dateregister' => $data['image_dateregister'],
            ];
        }

        return $data_array;
    }

    public function save( $args )
    {
       
        $sqlInstruction = 'CALL p_save_image( :image_id, :image_key, :image_path, :image_name, :image_description, :image_extension, :image_type, :image_header )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':image_id', $args['id'] , PDO::PARAM_INT);
        $statement->bindValue(':image_key', $args['key'] , PDO::PARAM_STR);
        $statement->bindValue(':image_path', $args['path'] , PDO::PARAM_STR);
        $statement->bindValue(':image_name', $args['name'] , PDO::PARAM_STR);
        $statement->bindValue(':image_description', $args['description'] , PDO::PARAM_STR);
        $statement->bindValue(':image_extension', $args['extension'] , PDO::PARAM_STR);
        $statement->bindValue(':image_type', $args['type'] , PDO::PARAM_STR);
        $statement->bindValue(':image_header', $args['image_header'] , PDO::PARAM_STR);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }


    public function delete( $id )
    {

        $sqlInstruction = 'CALL p_delete_image( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

}


