<?php 
namespace inshok\admin\database;

use \inshok\admin\database\ConnectionCreator;
use \inshok\admin\database\InterfaceBase;


use PDO;

class PdoTemplate implements InterfaceBase
{

    public function __construct()
    {
        
        $this->connection = ConnectionCreator::createConnection();

    }

    public function list( $id ) 
    {

        $sqlInstruction = 'CALL p_list_template( :ID, :page, :num_register, :identity )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->bindValue(':page', 0 , PDO::PARAM_INT);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->bindValue(':identity', TEMPLATE_PRIMARY , PDO::PARAM_STR);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return [
            'template_id' => $data['template_id'],
            'identity' => $data['template_identity'],
            'key' => $data['template_key'],
            'title' => $data['template_title'],
            'description' => $data['template_description'],
            'text' => $data['template_text'],
            'dateini' => $data['template_dateini'],
            'datefim' => $data['template_datefim'],
            'timeini' => $data['template_timeini'],
            'timefim' => $data['template_timefim'],
            'link' => $data['template_link'],
            'json' => $data['template_json'],
            'template_dateregister' => $data['template_dateregister'],
        ];
    }
    

    public function fulllist( $page ) 
    {

        $sqlInstruction = 'CALL p_list_template( :ID, :page, :num_register, :identity )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', 0 , PDO::PARAM_INT);
        $statement->bindValue(':page', $page , PDO::PARAM_INT);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->bindValue(':identity', TEMPLATE_PRIMARY , PDO::PARAM_STR);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'template_id' => $data['template_id'],
                'identity' => $data['template_identity'],
                'key' => $data['template_key'],
                'title' => $data['template_title'],
                'description' => $data['template_description'],
                'text' => $data['template_text'],
                'dateini' => $data['template_dateini'],
                'datefim' => $data['template_datefim'],
                'timeini' => $data['template_timeini'],
                'timefim' => $data['template_timefim'],
                'link' => $data['template_link'],
                'json' => $data['template_json'],
                'template_dateregister' => $data['template_dateregister'],
            ];
        }

        return $data_array;
    }


    public function totallist() {
        
        $sqlInstruction = 'CALL p_list_template_count_pages( :num_register, :identity )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->bindValue(':identity', TEMPLATE_PRIMARY , PDO::PARAM_STR);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return $data['v_num_pages'];

    }


    public function listbyCategory( $category , $page ) {


        $sqlInstruction = 'CALL p_list_template_by_category( :category_id, :page, :num_register, :identity )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':category_id', $category->getId() , PDO::PARAM_INT);
        $statement->bindValue(':page', $page , PDO::PARAM_INT);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->bindValue(':identity', TEMPLATE_PRIMARY , PDO::PARAM_STR);
        $statement->execute();
        
        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'template_id' => $data['template_id'],
                'identity' => $data['template_identity'],
                'key' => $data['template_key'],
                'title' => $data['template_title'],
                'description' => $data['template_description'],
                'text' => $data['template_text'],
                'dateini' => $data['template_dateini'],
                'datefim' => $data['template_datefim'],
                'timeini' => $data['template_timeini'],
                'timefim' => $data['template_timefim'],
                'link' => $data['template_link'],
                'json' => $data['template_json'],
                'template_dateregister' => $data['template_dateregister'],
                'templatecategory' => $data['templatecategory_id'],
            ];
        }

        return $data_array;

    }

    public function listCategory( $category_id ) 
    {

        $sqlInstruction = 'CALL p_list_templatecategory( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $category_id , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['template_id'],
                'identity' => $data['template_identity'],
                'key' => $data['template_key'],
                'title' => $data['template_title'],
                'description' => $data['template_description'],
                'text' => $data['template_text'],
                'dateini' => $data['template_dateini'],
                'datefim' => $data['template_datefim'],
                'timeini' => $data['template_timeini'],
                'timefim' => $data['template_timefim'],
                'link' => $data['template_link'],
                'json' => $data['template_json'],
                'dateregister' => $data['template_dateregister'],
            ];
        }

        return $data_array;
    }

    public function listGallery( $id ) 
    {

        $sqlInstruction = 'CALL p_list_templategallery( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['gallery_id'],
                'key' => $data['gallery_key'],
                'json' => $data['gallery_images_json'],
                'dateregister' => $data['template_dateregister'],
            ];
        }

        return $data_array;
    }

     public function listImage( $id ) 
    {

        $sqlInstruction = 'CALL p_list_templateimage( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['gallery_id'],
                'key' => $data['gallery_key'],
                'path' => $data['image_path'],
                'name' => $data['image_name'],
                'description' => $data['image_description'],
                'extension' => $data['image_extension'],
                'type' => $data['image_type'],
                'header' => $data['image_header'],
                'dateregister' => $data['template_dateregister'],
            ];
        }

        return $data_array;
    }



    public function save( $template )
    {


        $sqlInstruction = 'CALL p_save_template( :template_id, :template_identity, :template_key, :template_title, :template_description, :template_text, :template_dateini, :template_datefim, :template_timeini, :template_timefim, :template_link, :template_json )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':template_id', $template->getId() , PDO::PARAM_INT);
        $statement->bindValue(':template_identity', $template->getIdentity() , PDO::PARAM_STR);
        $statement->bindValue(':template_key', $template->getKey() , PDO::PARAM_STR);
        $statement->bindValue(':template_title', $template->getTitle() , PDO::PARAM_STR);
        $statement->bindValue(':template_description', $template->getDescription() , PDO::PARAM_STR);
        $statement->bindValue(':template_text', $template->getText() , PDO::PARAM_STR);
        $statement->bindValue(':template_dateini', $template->getDateini() , PDO::PARAM_STR);
        $statement->bindValue(':template_datefim', $template->getDatefim() , PDO::PARAM_STR);
        $statement->bindValue(':template_timeini', $template->getTimeini() , PDO::PARAM_STR);
        $statement->bindValue(':template_timefim', $template->getTimefim() , PDO::PARAM_STR);
        $statement->bindValue(':template_link', $template->getLink() , PDO::PARAM_STR);
        $statement->bindValue(':template_json', $template->getJson() , PDO::PARAM_STR);
        $statement->execute();


        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    public function saveTemplateCategory( $args )
    {

        $sqlInstruction = 'CALL p_save_templatecategory( :category_id, :template_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':category_id', $args['category_id'] , PDO::PARAM_INT);
        $statement->bindValue(':template_id', $args['template_id'] , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    public function saveTemplateGallery( $args )
    {

        $sqlInstruction = 'CALL p_save_templategallery( :template_id, :gallery_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':template_id', $args['template_id'] , PDO::PARAM_INT);
        $statement->bindValue(':gallery_id', $args['gallery_id'] , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    public function saveTemplateImage( $args )
    {

        $sqlInstruction = 'CALL p_save_templategallery( :template_id, :image_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':template_id', $args['template_id'] , PDO::PARAM_INT);
        $statement->bindValue(':image_id', $args['image_id'] , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }



    public function delete( $template )
    {

        $sqlInstruction = 'CALL p_delete_template( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $template->getId() , PDO::PARAM_INT);
        
        return $statement->execute();
    }


    public function deleteTemplateCategory( $template )
    {

        $sqlInstruction = 'CALL p_delete_templatecategory( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $template->getId() , PDO::PARAM_INT);
        
        return $statement->execute();
    }

    public function deleteTemplateGallery( $id )
    {

        $sqlInstruction = 'CALL p_delete_templategallery( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

    public function deleteTemplateImage( $id )
    {

        $sqlInstruction = 'CALL p_delete_templateimage( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

}


