<?php 
namespace inshok\admin\database;

use \inshok\admin\database\ConnectionCreator;
use \inshok\admin\database\InterfaceBase;


use PDO;

class PdoUser implements InterfaceBase
{

    public function __construct()
    {
        
        $this->connection = ConnectionCreator::createConnection();

    }


    public function fulllist( $page ) 
    {

        $sqlInstruction = 'CALL p_list_user( :ID, :page, :num_register )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', 0 , PDO::PARAM_INT);
        $statement->bindValue(':page', $page , PDO::PARAM_INT);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->execute();
        
        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'user_id' => $data['user_id'],
                'name' => $data['user_name'],
                'lastname' => $data['user_lastname'],
                'email' => $data['user_email'],
                'dateregister' => $data['user_dateregister']
            ];
        }
        
        return $data_array;
    }


    
    public function list( $id ) 
    {

        $sqlInstruction = 'CALL p_list_user( :ID, :page, :num_register )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->bindValue(':page', 0 , PDO::PARAM_INT);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return [
            'user_id' => $data['user_id'],
            'email' => $data['user_email'],
            'name' => $data['user_name'],
            'lastname' => $data['user_lastname'],
            'dateregister' => $data['user_dateregister']
        ];
    }
    
    
    public function listupdate( $id ) 
    {

        $sqlInstruction = 'CALL p_list_user_update( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->execute();

        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return [
            'user_id' => $data['user_id'],
            'email' => $data['user_email'],
            'name' => $data['user_name'],
            'lastname' => $data['user_lastname'],
            'user_dateregister' => $data['user_dateregister'],
            'documents_id' => $data['documents_id'],
            'cpf' => $data['documents_cpf'],
            'rg' => $data['documents_rg'],
            'documents_dateregister' => $data['documents_dateregister'],
            'contacts_id' => $data['contacts_id'],
            'whatsapp' => $data['contacts_whatsapp'],
            'contacts_dateregister' => $data['contacts_dateregister'],
        ];
    }

    public function listcontacts( $user ) 
    {

        $sqlInstruction = 'CALL p_list_usercontacts( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $user->getId() , PDO::PARAM_INT);
        $statement->execute();

        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return [
            'contacts_id' => $data['contacts_id'],
            'phone' => $data['contacts_phone'],
            'landline' => $data['contacts_landline'],
            'whatsapp' => $data['contacts_whatsapp'],
            'email1' => $data['contacts_email1'],
            'email2' => $data['contacts_email2'],
            'email3' => $data['contacts_email3'],
            'contacts_dateregister' => $data['contacts_dateregister'],
        ];
    }

    public function listAddress( $user ) 
    {

        $sqlInstruction = 'CALL p_list_useraddress( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $user->getId() , PDO::PARAM_INT);
        $statement->execute();

        $data = $statement->fetch(PDO::FETCH_ASSOC);


        if( !$data ) return false;

        return [
            'address_id' => $data['address_id'],
            'rua' => $data['address_rua'],
            'numero' => $data['address_numero'],
            'complemento' => $data['address_complemento'],
            'bairro' => $data['address_bairro'],
            'cidade' => $data['address_cidade'],
            'estado' => $data['address_estado'],
            'pais' => $data['address_pais'],
            'cep' => $data['address_cep'],
            'address_dateregister' => $data['address_dateregister'],
        ];
    }

    public function listLogin( $user ) 
    {

        $sqlInstruction = 'CALL p_list_userlogin( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $user->getId() , PDO::PARAM_INT);
        $statement->execute();

        $data = $statement->fetch(PDO::FETCH_ASSOC);

        if( !$data ) return false;

        return [
            'login_id' => $data['login_id'],
            'key' => $data['login_key'],
            'pass' => $data['login_pass'],
            'login_lastaccess' => $data['login_lastaccess'],
            'login_dateregister' => $data['login_dateregister'],
        ];
    }


    

    
    public function totallist() {
        
        $sqlInstruction = 'CALL p_list_user_count_pages( :num_register )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':num_register', REGISTER_PAGINATION , PDO::PARAM_INT);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return $data['v_num_pages'];

    }


    public function save( $user )
    {

        $sqlInstruction = 'CALL p_save_user( :user_id, :user_email, :user_name,  :user_lastname )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $user->getId() , PDO::PARAM_INT);
        $statement->bindValue(':user_email', $user->getEmail() , PDO::PARAM_STR);
        $statement->bindValue(':user_name', $user->getName() , PDO::PARAM_STR);
        $statement->bindValue(':user_lastname', $user->getLastname() , PDO::PARAM_STR);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    
    public function saveDocuments( $user , $documents )
    {

        $sqlInstruction = 'CALL p_save_userdocuments( :user_id, :documents_cpf, :documents_rg )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $user->getId() , PDO::PARAM_INT);
        $statement->bindValue(':documents_cpf', $documents->getCpf() , PDO::PARAM_STR);
        $statement->bindValue(':documents_rg', $documents->getRg() , PDO::PARAM_STR);
        
        return $statement->execute();
        
    }

    

    public function saveContacts( $user , $contacts )
    {

        $sqlInstruction = 'CALL p_save_usercontacts( :user_id, :phone, :landline, :whatsapp, :email1, :email2, :email3 )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $user->getId() , PDO::PARAM_INT);
        $statement->bindValue(':phone', $contacts->getPhone() , PDO::PARAM_STR);
        $statement->bindValue(':landline', $contacts->getLandline() , PDO::PARAM_STR);
        $statement->bindValue(':whatsapp', $contacts->getWhatsapp() , PDO::PARAM_STR);
        $statement->bindValue(':email1', $contacts->getEmail1() , PDO::PARAM_STR);
        $statement->bindValue(':email2', $contacts->getEmail2() , PDO::PARAM_STR);
        $statement->bindValue(':email3', $contacts->getEmail3() , PDO::PARAM_STR);
        
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    public function saveAddress( $user , $address )
    {

        $sqlInstruction = 'CALL p_save_useraddress( :user_id, :cep, :rua, :numero, :complemento, :bairro, :cidade, :estado, :pais )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $user->getId() , PDO::PARAM_INT);
        $statement->bindValue(':cep', $address->getCep() , PDO::PARAM_STR);
        $statement->bindValue(':rua', $address->getRua() , PDO::PARAM_STR);
        $statement->bindValue(':numero', $address->getNumero() , PDO::PARAM_STR);
        $statement->bindValue(':complemento', $address->getComplemento() , PDO::PARAM_STR);
        $statement->bindValue(':bairro', $address->getBairro() , PDO::PARAM_STR);
        $statement->bindValue(':cidade', $address->getCidade() , PDO::PARAM_STR);
        $statement->bindValue(':estado', $address->getEstado() , PDO::PARAM_STR);
        $statement->bindValue(':pais', $address->getPais() , PDO::PARAM_STR);
        
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }


    
    public function savePass( $user , $login )
    {

        $sqlInstruction = 'CALL p_save_userlogin( :user_id, :login_pass, :login_key )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $user->getId() , PDO::PARAM_INT);
        $statement->bindValue(':login_pass', $login->getPass() , PDO::PARAM_STR);
        $statement->bindValue(':login_key', $login->getKey() , PDO::PARAM_STR);
       
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }



    public function delete( $id )
    {

        $sqlInstruction = 'CALL p_delete_user( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

}


