<?php 
namespace inshok\admin\database;

use \inshok\admin\database\ConnectionCreator;
use \inshok\admin\database\InterfaceBase;


use PDO;

class PdoMolecules implements InterfaceBase
{

    public function __construct()
    {
        
        $this->connection = ConnectionCreator::createConnection();

    }

    public function list( $id ) 
    {

        $sqlInstruction = 'CALL p_list_molecules( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return [
            'id' => $data['molecules_id'],
            'key' => $data['molecules_key'],
            'type' => $data['molecules_type'],
            'value' => $data['molecules_value'],
            'json' => $data['molecules_json'],
            'dateregister' => $data['molecules_dateregister'],
        ];
    }


    public function fulllist() 
    {

        $sqlInstruction = 'CALL p_list_molecules( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', 0 , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['molecules_id'],
                'key' => $data['molecules_key'],
                'type' => $data['molecules_type'],
                'value' => $data['molecules_value'],
                'json' => $data['molecules_json'],
                'dateregister' => $data['molecules_dateregister'],
            ];
        }

        return $data_array;
    }

    public function listMoleculesOrganisms( $id_organisms ) 
    {

        $sqlInstruction = 'CALL p_list_moleculesorganisms( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id_organisms , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['molecules_id'],
                'key' => $data['molecules_key'],
                'type' => $data['molecules_type'],
                'value' => $data['molecules_value'],
                'json' => $data['molecules_json'],
                'dateregister' => $data['molecules_dateregister'],
            ];
        }

        return $data_array;
    }

    public function save( $args )
    {

        $sqlInstruction = 'CALL p_save_molecules( :molecules_id, :molecules_key, :molecules_type, :molecules_value, :molecules_json )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':molecules_id', $args['id'] , PDO::PARAM_INT);
        $statement->bindValue(':molecules_key', $args['key'] , PDO::PARAM_STR);
        $statement->bindValue(':molecules_type', $args['type'] , PDO::PARAM_STR);
        $statement->bindValue(':molecules_value', $args['value'] , PDO::PARAM_STR);
        $statement->bindValue(':molecules_json', $args['json'] , PDO::PARAM_STR);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    public function saveMoleculesOrganisms( $args )
    {

        $sqlInstruction = 'CALL p_save_moleculesorganisms( :organisms_id, :molecules_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':organisms_id', $args['organisms_id'] , PDO::PARAM_INT);
        $statement->bindValue(':molecules_id', $args['molecules_id'] , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }



    public function delete( $id )
    {

        $sqlInstruction = 'CALL p_delete_molecules( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

    public function deleteMoleculesOrganisms( $id )
    {

        $sqlInstruction = 'CALL p_delete_moleculesorganisms( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

}


