<?php 
namespace inshok\admin\database;

use \inshok\admin\database\ConnectionCreator;
use \inshok\admin\database\InterfaceBase;


use PDO;

class PdoOrganisms implements InterfaceBase
{

    public function __construct()
    {
        
        $this->connection = ConnectionCreator::createConnection();

    }

    public function list( $id ) 
    {

        $sqlInstruction = 'CALL p_list_organisms( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return [
            'id' => $data['organisms_id'],
            'key' => $data['organisms_key'],
            'title' => $data['organisms_title'],
            'description' => $data['organisms_description'],
            'text' => $data['organisms_text'],
            'dateini' => $data['organisms_dateini'],
            'datefim' => $data['organisms_datefim'],
            'timeini' => $data['organisms_timeini'],
            'timefim' => $data['organisms_timefim'],
            'link' => $data['organisms_link'],
            'json' => $data['organisms_json'],
            'dateregister' => $data['organisms_dateregister'],
        ];
    }


    public function fulllist() 
    {

        $sqlInstruction = 'CALL p_list_organisms( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', 0 , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['organisms_id'],
                'key' => $data['organisms_key'],
                'title' => $data['organisms_title'],
                'description' => $data['organisms_description'],
                'text' => $data['organisms_text'],
                'dateini' => $data['organisms_dateini'],
                'datefim' => $data['organisms_datefim'],
                'timeini' => $data['organisms_timeini'],
                'timefim' => $data['organisms_timefim'],
                'link' => $data['organisms_link'],
                'json' => $data['organisms_json'],
                'dateregister' => $data['organisms_dateregister'],
            ];
        }

        return $data_array;
    }

    public function listAddress( $id ) 
    {

        $sqlInstruction = 'CALL p_list_organismsaddress( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['address_id'],
                'rua' => $data['address_rua'],
                'numero' => $data['address_numero'],
                'complemento' => $data['address_complemento'],
                'bairro' => $data['address_bairro'],
                'cidade' => $data['address_cidade'],
                'estado' => $data['address_estado'],
                'pais' => $data['address_pais'],
                'cep' => $data['address_cep'],
                'dateregister' => $data['address_dateregister'],
            ];
        }

        return $data_array;
    }

    public function listContacts( $id ) 
    {

        $sqlInstruction = 'CALL p_list_organismscontacts( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['contacts_id'],
                'key' => $data['contacts_key'],
                'type' => $data['contacts_type'],
                'value' => $data['contacts_value'],
                'dateregister' => $data['contacts_dateregister'],
            ];
        }

        return $data_array;
    }

    public function listByTemplate( $id_template ) 
    {

        $sqlInstruction = 'CALL p_list_organismstemplate( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id_template , PDO::PARAM_INT);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'id' => $data['organisms_id'],
                'key' => $data['organisms_key'],
                'title' => $data['organisms_title'],
                'description' => $data['organisms_description'],
                'text' => $data['organisms_text'],
                'dateini' => $data['organisms_dateini'],
                'datefim' => $data['organisms_datefim'],
                'timeini' => $data['organisms_timeini'],
                'timefim' => $data['organisms_timefim'],
                'link' => $data['organisms_link'],
                'json' => $data['organisms_json'],
                'dateregister' => $data['organisms_dateregister'],
            ];
        }

        return $data_array;
    }

    public function save( $args )
    {

        $sqlInstruction = 'CALL p_save_organisms( :organisms_id, :organisms_key, :organisms_title, :organisms_description, :organisms_text, :organisms_dateini, :organisms_datefim, :organisms_timeini, :organisms_timefim, :organisms_link, :organisms_json )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':organisms_id', $args['id'] , PDO::PARAM_INT);
        $statement->bindValue(':organisms_key', $args['key'] , PDO::PARAM_STR);
        $statement->bindValue(':organisms_title', $args['title'] , PDO::PARAM_STR);
        $statement->bindValue(':organisms_description', $args['description'] , PDO::PARAM_STR);
        $statement->bindValue(':organisms_text', $args['text'] , PDO::PARAM_STR);
        $statement->bindValue(':organisms_dateini', $args['dateini'] , PDO::PARAM_STR);
        $statement->bindValue(':organisms_datefim', $args['datefim'] , PDO::PARAM_STR);
        $statement->bindValue(':organisms_timeini', $args['timeini'] , PDO::PARAM_STR);
        $statement->bindValue(':organisms_timefim', $args['timefim'] , PDO::PARAM_STR);
        $statement->bindValue(':organisms_link', $args['link'] , PDO::PARAM_STR);
        $statement->bindValue(':organisms_json', $args['json'] , PDO::PARAM_STR);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    public function saveAddress( $args )
    {

        $sqlInstruction = 'CALL p_save_organismsaddress( :address_id, :organisms_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':address_id', $args['address_id'] , PDO::PARAM_INT);
        $statement->bindValue(':organisms_id', $args['organisms_id'] , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    public function saveConatcts( $args )
    {

        $sqlInstruction = 'CALL p_save_organismscontacts( :contacts_id, :organisms_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':contacts_id', $args['contacts_id'] , PDO::PARAM_INT);
        $statement->bindValue(':organisms_id', $args['organisms_id'] , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }

    public function saveByTemplate( $args )
    {

        $sqlInstruction = 'CALL p_save_organismsorganisms( :template_id, :organisms_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':template_id', $args['template_id'] , PDO::PARAM_INT);
        $statement->bindValue(':organisms_id', $args['organisms_id'] , PDO::PARAM_INT);
        $statement->execute();

        return $statement->fetch(PDO::FETCH_ASSOC);
        
    }



    public function delete( $id )
    {

        $sqlInstruction = 'CALL p_delete_organisms( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

    public function deleteAddress( $id )
    {

        $sqlInstruction = 'CALL p_delete_organismsaddress( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

    public function deleteContacts( $id )
    {

        $sqlInstruction = 'CALL p_delete_organismscontacts( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

    public function deleteByTemplate( $id )
    {

        $sqlInstruction = 'CALL p_delete_organismstemplate( :ID )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':ID', $id , PDO::PARAM_INT);
        
        return $statement->execute();
    }

}


