import { FormatMaskCelPhone } from './FormatMaskCelPhone.js';
import { FormatMaskCPF } from './FormatMaskCPF.js';
import { Validation } from './Validation.js';



export class Register extends Validation
{
    constructor( errorMessages , validators )
    {
        super( errorMessages , validators );
    }

    validate( input )
    {
        return super._validate( input );
    }

    validateName( args )
    {
        const input = args['name'];
        let message = '';
        let name = args.name.value;

        let name_split = name.split(' ');
        if(name_split.length <= 1) {
            message = 'Você precisa digitar o nome e o sobrenome';
        }


        input.setCustomValidity(message);
    }

    
    formatWhatsapp( args ) 
    {
        args.whatsapp.value = FormatMaskCelPhone.cel(args.whatsapp.value);
        return true;
    }


    compareInputs( args ) {
        
        let message = '';
        if(args.pass.value != args.repass.value) {
            message = 'As senhas não correspondem.';
        }

        args.repass.setCustomValidity(message);
        
    }


    //
    validateCPF( args ) {
        
        const input = args['cpf'];
        const CPFFormating = input.value.replace(/\D/g, '');
        let message = '';


        if(!this._checkCPFRepeated(CPFFormating) || !this._checkCPFStructure(CPFFormating)) {
            message = 'O CPF não é válido';
        }

        input.setCustomValidity(message);
        
        args.cpf.value = FormatMaskCPF.format( args.cpf.value );
    }

    _checkCPFRepeated(cpf) {
        const repeatedValues = [
            '00000000000',
            '11111111111',
            '22222222222',
            '33333333333',
            '44444444444',
            '55555555555',
            '66666666666',
            '77777777777',
            '88888888888',
            '99999999999',
        ]

        let CPFValidate = true;
        repeatedValues.forEach(value => {
            if(value == cpf) {
                CPFValidate = false;
            }
        })

        return CPFValidate;
    }

    _checkCPFStructure(cpf) {
        let multiplier = 10;
        return this._checkVerifyingDigit(cpf, multiplier);
    }


    _checkVerifyingDigit(cpf, multiplier) {

        if(multiplier >= 12) {
            return true;
        }

        let initialMultiplier = multiplier;
        let sum = 0;
        const cpfNoDigit = cpf.substr(0, multiplier - 1).split('');
        const digitVerify = parseInt(cpf.charAt(multiplier - 1));

        for(let counter = 0; initialMultiplier > 1; initialMultiplier--) {
            sum = sum + parseInt(cpfNoDigit[counter]) * initialMultiplier;
            counter++;
        }

        if(digitVerify == this._confirmDigit(sum)) {
            return this._checkVerifyingDigit(cpf, multiplier + 1);
        }

        return false;
    }


    _confirmDigit(sum) {
        let rest = 11 - (sum % 11);
        if(rest == 11 || rest == 10) rest = 0;
        return rest;
    }


        
    //
    recoverCEP( args ) {

        const cep = args['cep'];

        if( cep.value.length != 8 ) {
            cep.setCustomValidity('CEP inválido');
            return;
        }

        
        const CEPFormating = cep.value.replace(/\D/g, '');
        const url = `https://viacep.com.br/ws/${CEPFormating}/json/`;
        const options = {
            method: 'GET',
            mode: 'cors',
            headers: {
                'content-type': 'application/json; charset:utf-8'
            }
        }

        if(!cep.validity.patternMismatch && !cep.validity.valueMissing) {

            fetch(url, options).then(

                response => response.json()

            ).then (
                data => {

                    if(data.erro) {
                        cep.setCustomValidity('CEP inválido');
                        return;
                    }

                    cep.setCustomValidity('');
                    this._fillFeelds( data , args );
                    return;
                }
            )
        }
    }


    _fillFeelds( data , args ) {
        args['rua'].value = data.logradouro;
        args['bairro'].value = data.bairro;
        args['cidade'].value = data.localidade;
        args['estado'].value = data.uf;
        args['pais'].value = 'Brasil';
    }



    validateKeyLogin( args ) {

        const key = args['key'];
        console.log(key.value);
        console.log(key.value.indexOf(' '));

        if(key.value.indexOf(' ') >= 0) {
            key.setCustomValidity(true);
            return;
        }

        key.setCustomValidity('');
    
    }



}

